@@ -186,7 +186,7 @@
 #define SIZEOF_UINTPTR_T 8
 #define HAVE_SSIZE_T 1
 #define SIZEOF_SSIZE_T 8
-#define HEAP_ALIGN_LOG 12
+#define HEAP_PAGE_ALIGN_LOG 12
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA 1
@@ -356,6 +356,7 @@
 #define UCONTEXT_IN_SIGNAL_H 1
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t *mc = &(uc)->uc_mcontext
 #define USE_ELF 1
+#define HAVE_ELF_H 1
 #define HAVE_ELF_ABI_H 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
