@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.3) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.4.6) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4/mips64el-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "3"
-  CONFIG["PATCHLEVEL"] = "205"
-  CONFIG["INSTALL"] = '/usr/ports/pobj/ruby-2.4.3/bin/install -c '
+  CONFIG["TEENY"] = "6"
+  CONFIG["PATCHLEVEL"] = "354"
+  CONFIG["INSTALL"] = '/home/pea/pobj/ruby-2.4.6/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)24"
@@ -144,9 +144,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/ports/pobj/ruby-2.4.3/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/ports/pobj/ruby-2.4.3/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/ports/pobj/ruby-2.4.3/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/home/pea/pobj/ruby-2.4.6/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/home/pea/pobj/ruby-2.4.6/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/home/pea/pobj/ruby-2.4.6/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -183,22 +183,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd6.3"
+  CONFIG["target_os"] = "openbsd6.5"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64el"
-  CONFIG["target"] = "mips64el-unknown-openbsd6.3"
-  CONFIG["host_os"] = "openbsd6.3"
+  CONFIG["target"] = "mips64el-unknown-openbsd6.5"
+  CONFIG["host_os"] = "openbsd6.5"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64el"
-  CONFIG["host"] = "mips64el-unknown-openbsd6.3"
+  CONFIG["host"] = "mips64el-unknown-openbsd6.5"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.3"
+  CONFIG["build_os"] = "openbsd6.5"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64el"
-  CONFIG["build"] = "mips64el-unknown-openbsd6.3"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.3"
+  CONFIG["build"] = "mips64el-unknown-openbsd6.5"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.6"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
@@ -221,6 +221,7 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
+  CONFIG["runstatedir"] = "$(localstatedir)/run"
   CONFIG["localstatedir"] = "$(DESTDIR)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
