@@ -1,3 +1,4 @@
+# frozen_string_literal: false
 #
 # = net/protocol.rb
 #
@@ -11,7 +12,7 @@
 # modify this program under the same terms as Ruby itself,
 # Ruby Distribute License or GNU General Public License.
 #
-# $Id: protocol.rb 46515 2014-06-23 09:36:03Z usa $
+# $Id: protocol.rb 56779 2016-11-14 07:53:32Z nobu $
 #++
 #
 # WARNING: This file is going to remove.
@@ -20,6 +21,7 @@
 
 require 'socket'
 require 'timeout'
+require 'io/wait'
 
 module Net # :nodoc:
 
@@ -32,6 +34,24 @@ module Net # :nodoc:
         end
       End
     end
+
+    def ssl_socket_connect(s, timeout)
+      if timeout
+        while true
+          raise Net::OpenTimeout if timeout <= 0
+          start = Process.clock_gettime Process::CLOCK_MONOTONIC
+          # to_io is required because SSLSocket doesn't have wait_readable yet
+          case s.connect_nonblock(exception: false)
+          when :wait_readable; s.to_io.wait_readable(timeout)
+          when :wait_writable; s.to_io.wait_writable(timeout)
+          else; break
+          end
+          timeout -= Process.clock_gettime(Process::CLOCK_MONOTONIC) - start
+        end
+      else
+        s.connect
+      end
+    end
   end
 
 
@@ -59,11 +79,11 @@ module Net # :nodoc:
 
 
   class BufferedIO   #:nodoc: internal use only
-    def initialize(io)
+    def initialize(io, read_timeout: 60, continue_timeout: nil, debug_output: nil)
       @io = io
-      @read_timeout = 60
-      @continue_timeout = nil
-      @debug_output = nil
+      @read_timeout = read_timeout
+      @continue_timeout = continue_timeout
+      @debug_output = debug_output
       @rbuf = ''
     end
 
@@ -149,23 +169,21 @@ module Net # :nodoc:
     BUFSIZE = 1024 * 16
 
     def rbuf_fill
-      begin
-        @rbuf << @io.read_nonblock(BUFSIZE)
-      rescue IO::WaitReadable
-        if IO.select([@io], nil, nil, @read_timeout)
-          retry
-        else
-          raise Net::ReadTimeout
-        end
-      rescue IO::WaitWritable
+      case rv = @io.read_nonblock(BUFSIZE, exception: false)
+      when String
+        return @rbuf << rv
+      when :wait_readable
+        @io.to_io.wait_readable(@read_timeout) or raise Net::ReadTimeout
+        # continue looping
+      when :wait_writable
         # OpenSSL::Buffering#read_nonblock may fail with IO::WaitWritable.
         # http://www.openssl.org/support/faq.html#PROG10
-        if IO.select(nil, [@io], nil, @read_timeout)
-          retry
-        else
-          raise Net::ReadTimeout
-        end
-      end
+        @io.to_io.wait_writable(@read_timeout) or raise Net::ReadTimeout
+        # continue looping
+      when nil
+        # callers do not care about backtrace, so avoid allocating for it
+        raise EOFError, 'end of file reached', []
+      end while true
     end
 
     def rbuf_consume(len)
@@ -236,7 +254,7 @@ module Net # :nodoc:
 
 
   class InternetMessageIO < BufferedIO   #:nodoc: internal use only
-    def initialize(io)
+    def initialize(*)
       super
       @wbuf = nil
     end
